@@ -27,20 +27,22 @@
 // - observeRequest(uri, request)  // This doesn't exist !!!  It is for future
 // - observeGRequest(uri, method)  // This is only for Generator
 // - observeResponse(uri, request, response, postData, isRedirect)
+if(!livehttpheaders) var livehttpheaders={};
+if(!livehttpheaders.live) livehttpheaders.live={};
 
-var oHeaderInfoLive;
-function startHeaderInfoLive() {
-  oHeaderInfoLive = new HeaderInfoLive();
-  oHeaderInfoLive.start();
-  addToListener(oHeaderInfoLive)
+livehttpheaders.live.oHeaderInfoLive = null;
+livehttpheaders.live.startHeaderInfoLive = function() {
+  livehttpheaders.live.oHeaderInfoLive = new livehttpheaders.live.HeaderInfoLive();
+  livehttpheaders.live.oHeaderInfoLive.start();
+  livehttpheaders.live.addToListener(livehttpheaders.live.oHeaderInfoLive)
 }
-function stopHeaderInfoLive() {
-  removeFromListener(oHeaderInfoLive)
-  oHeaderInfoLive.stop();
-  oHeaderInfoLive = null;
+livehttpheaders.live.stopHeaderInfoLive = function() {
+  livehttpheaders.live.removeFromListener(livehttpheaders.live.oHeaderInfoLive)
+  livehttpheaders.live.oHeaderInfoLive.stop();
+  livehttpheaders.live.oHeaderInfoLive = null;
 }
 
-function addToListener(obj)
+livehttpheaders.live.addToListener = function(obj)
 {
   // Register new request and response listener
   if ('nsINetModuleMgr' in Components.interfaces) {
@@ -55,7 +57,7 @@ function addToListener(obj)
     observerService.addObserver(obj, "http-on-examine-response", false);
   }
 }
-function removeFromListener(obj)
+livehttpheaders.live.removeFromListener = function(obj)
 {
   // Unregistering listener
   if ('nsINetModuleMgr' in Components.interfaces) {
@@ -71,7 +73,7 @@ function removeFromListener(obj)
   }
 }
 
-function HeaderInfoLive()
+livehttpheaders.live.HeaderInfoLive = function()
 {
   this.test = new Array(); //Test
   this.data = new Array(); //Data for each row
@@ -95,7 +97,7 @@ function HeaderInfoLive()
   this.useexclude  = this.getBoolPref(this.lpref, "exclude", false); // exclude mode
   this.excludeRegexp  = this.getCharPref(this.lpref, "excludeRegexp",'\.gif$|\.jpg$|\.ico$|\.css$|\.js$'); // exclude mode
 }
-HeaderInfoLive.prototype =
+livehttpheaders.live.HeaderInfoLive.prototype =
 {
   // Constants
   // Type
@@ -231,7 +233,7 @@ HeaderInfoLive.prototype =
   hScrollHandler: function() {
     // Need to use global oHeaderInfoLive object  this because 'this'
     // doesn't seem to be available.
-    var base = oHeaderInfoLive;
+    var base = livehttpheaders.live.oHeaderInfoLive;
     var curpos = base.hScrollBar.attributes.getNamedItem("curpos").value;
     if (curpos != base.hScrollPos) {
       base.hScrollPos = curpos;
@@ -242,12 +244,15 @@ HeaderInfoLive.prototype =
   // Select and copy function
   onselect: function()
   {
+    var replay = document.getElementById("headerinfo-replay");
+    if (!replay)
+      return;
     var selection = this.oDump.view.selection;
     // Look if there is an URL block selected
     if (selection.count == 1 && this.type[selection.currentIndex]!=this.SEPARATOR) {
-      document.getElementById("headerinfo-replay").disabled = false;
+      replay.disabled = false;
     } else {
-      document.getElementById("headerinfo-replay").disabled = true;
+      replay.disabled = true;
     }
   },
 
@@ -270,17 +275,7 @@ HeaderInfoLive.prototype =
   },
  
   toClipboard: function(data) {
-    if (data) {
-      // clipboard helper
-      try
-      {
-        const clipboardHelper = Components.classes["@mozilla.org/widget/clipboardhelper;1"].getService(Components.interfaces.nsIClipboardHelper);
-	clipboardHelper.copyString(data);
-      } catch(e) {
-        // do nothing, later code will handle the error
-	dump("Unable to get the clipboard helper\n");
-      }
-    }
+    livehttpheaders.info.toClipboard(data);
   },
   
   copy: function()
@@ -462,12 +457,12 @@ HeaderInfoLive.prototype =
 
   saveAll: function(title)
   {
-    saveAs(this.getAll(),title);
+    livehttpheaders.info.saveAs(this.getAll(),title);
   },
   
   saveSelection: function(title)
   {
-    saveAs(this.getSelection(),title);
+    livehttpheaders.info.saveAs(this.getSelection(),title);
   },
 
   replay: function()
@@ -739,7 +734,7 @@ HeaderInfoLive.prototype =
   {
     var name = oHttp.URI.asciiSpec;
     var origname = oHttp.originalURI.asciiSpec;
-    var visitor = new HeaderInfoVisitor(oHttp);
+    var visitor = new livehttpheaders.live.HeaderInfoVisitor(oHttp);
     //dumpall("oHttp",oHttp,2);
     //alert("REsponse: " + oHttp)
     //alert(this.test[oHttp])
@@ -812,16 +807,29 @@ HeaderInfoLive.prototype =
     }
 }
 
-function HeaderInfoVisitor (oHttp)
+livehttpheaders.live.HeaderInfoVisitor = function(oHttp)
 {
   //dump("HeaderInfoVisitor\n");
   this.oHttp = oHttp;
   this.headers = new Array();
 }
-HeaderInfoVisitor.prototype = 
+livehttpheaders.live.HeaderInfoVisitor.prototype = 
 {
   oHttp : null,
   headers : null,
+  getHttpResponseVersion: function ()
+  {
+    var version = "1.z"; // Default value
+    // Check if this is Mozilla v1.5a and more
+    try {
+      var maj = new Object();
+      var min = new Object();
+      this.oHttp.QueryInterface(Components.interfaces.nsIHttpChannelInternal);
+      this.oHttp.getResponseVersion(maj,min);
+      version = "" + maj.value + "."+ min.value;
+    } catch (ex) {}
+    return version;
+  },
   getHttpRequestVersion: function (httpProxy)
   {
     var version = "1.0"; // Default value for direct HTTP and proxy HTTP
@@ -846,24 +854,41 @@ HeaderInfoVisitor.prototype =
     try {
       var pps = Components.classes["@mozilla.org/network/protocol-proxy-service;1"].getService().QueryInterface(Components.interfaces.nsIProtocolProxyService);
       
-      // If a proxy is used for this url, we need to keep the host part
-      if (pps.proxyEnabled && (pps.examineForProxy(uri)!=null)) {
-        // Proxies are enabled.  Now, check if it is an HTTP proxy.
-        var pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService);
-        pref = pref.getBranch("");
-        // Now, get the value of the HTTP proxy fields
-        var http_host = pref.getCharPref("network.proxy.http");
-        var http_port = pref.getIntPref("network.proxy.http_port");
-        // network.proxy.http_port network.proxy.http
-        if (http_host && http_port>0) {
-          return true; // HTTP Proxy
-        } 
-      } 
+          // If a proxy is used for this url, we need to keep the host part
+      if (typeof(pps.proxyEnabled) != "undefined") {
+        // Mozilla up to 1.7
+        if (pps.proxyEnabled && (pps.examineForProxy(uri)!=null)) {
+          // Proxies are enabled.  Now, check if it is an HTTP proxy.
+          return this.isHttpProxy();
+        }
+      } else {
+        // Firefox and Mozilla 1.8+
+        if (pps.resolve(uri, pps.RESOLVE_NON_BLOCKING)!=null) {
+          // Proxies are enabled.  Now, check if it is an HTTP proxy.
+          return this.isHttpProxy();
+        }
+      }
       return false; // No proxy or not HTTP Proxy
     } catch (ex) {
       return null; // Error
     }
   },
+
+  isHttpProxy : function()
+  {
+    // Check if an HTTP proxy is configured.
+    var pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService);
+    pref = pref.getBranch("");
+    // Now, get the value of the HTTP proxy fields
+    var http_host = pref.getCharPref("network.proxy.http");
+    var http_port = pref.getIntPref("network.proxy.http_port");
+    // network.proxy.http_port network.proxy.http
+    if (http_host && http_port>0) {
+      return true; // HTTP Proxy
+    }
+    return false;
+  },
+
   getPostData : function(oHttp) {
     function postData(stream) {
       // Scriptable Stream Constants
@@ -968,8 +993,10 @@ HeaderInfoVisitor.prototype =
           return ""+ex;
         } finally {
           // Need to close the stream after use.  
-          this.seekablestream.close();
-          this.stream.close();
+          //this.seekablestream.close();
+          //this.stream.close();
+          //this.seekablestream.seek(2,0);
+          try { this.stream.read(this.stream.available()); } catch (ex) {}
         }
 	return postString;
       }
@@ -1037,8 +1064,9 @@ HeaderInfoVisitor.prototype =
   },
   visitResponse : function ()
   {
+    var ver = this.getHttpResponseVersion();
     this.headers = new Array();
-    this.headers["RESPONSE"] = "HTTP/1.x " + this.oHttp.responseStatus 
+    this.headers["RESPONSE"] = "HTTP/" + ver + " " + this.oHttp.responseStatus 
                     + " " + this.oHttp.responseStatusText;
     //this.headers["loadGroup"] = this.oHttp.loadGroup
     //this.headers["owner"] = this.oHttp.owner
