@@ -131,7 +131,7 @@ livehttpheaders.nshi.nsHeaderInfo = {
       //} else if (aTopic == 'http-on-examine-response') {
       //  aSubject.QueryInterface(Components.interfaces.nsIHttpChannel);
       //  this.onExamineResponse(aSubject);
-      } else if (aTopic == 'app-startup') {
+      } else if (aTopic == 'app-startup' || aTopic == 'profile-after-change') {
         if ('nsINetModuleMgr' in Components.interfaces) {
 	    // Should be an old version of Mozilla (before september 15, 2003
           var netModuleMgr = Components.classes["@mozilla.org/network/net-extern-mod;1"].getService(Components.interfaces.nsINetModuleMgr);
@@ -142,7 +142,7 @@ livehttpheaders.nshi.nsHeaderInfo = {
           var observerService = Components.classes["@mozilla.org/observer-service;1"].getService(Components.interfaces.nsIObserverService);
           observerService.addObserver(livehttpheaders.nshi.nsHeaderInfo, "http-on-modify-request", false);
           //observerService.addObserver(nsHeaderInfo, "http-on-examine-response", false);
-	}
+	    }
         
         // Initialisation of all needed vars 
         this.observers = new Array();
@@ -428,6 +428,7 @@ livehttpheaders.nshi.FakeController.prototype = {
 
 /* nsHeaderInfo Module (for XPCOM registration) */
 livehttpheaders.nshi.nsHeaderInfoModule = {
+    classID: Components.ID("{d5598f0d-5eba-43bc-b8e1-342a23bce3ea}"),
     firstTime : true,
     registerSelf: function(compMgr, fileSpec, location, type) {
       dump("nsHeaderInfo: registerSelf called!\n");
@@ -489,4 +490,5 @@ livehttpheaders.nshi.nsHeaderInfoFactory = {
 
 /* module initialisation */
 function NSGetModule(comMgr, fileSpec) { return livehttpheaders.nshi.nsHeaderInfoModule; }
+function NSGetFactory(cid) { return livehttpheaders.nshi.nsHeaderInfoFactory; }
 
